.. cfficloak documentation master file, created by
   sphinx-quickstart on Sun Sep  8 23:42:47 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to cfficloak's documentation!
=====================================

CFFIwrap is a set of convenience functions and wrapper classes designed to
make writing CFFI modules less tedious. The source tree contains a single
python module called cfficloak.py. 
Simply install cfficloak with:
Install with 
> pip install cfficloak
or 
> pip install https://github.com/andrewleech/cfficloak/archive/master.zip
For more examples take a look in the tests directory.

This project is licensed under the Apache License, version 2.0.

.. toctree::
   :maxdepth: 4

Module documentation
====================
.. automodule:: cfficloak
    :members:
    :undoc-members:
    :show-inheritance:

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

